import{O as d}from"./workspaceStore-sWJCG1kE.js";import{e as c,R as u,f,v as o,w as n,p as t,an as _,T as p,q as r,t as s,l as i,g as b}from"./jwt-decode.esm-Da8x-1xB.js";import"./userStore-B4jqUwEL.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="15f1eb19-511d-4c3e-8417-8a18a3aaa1ec",e._sentryDebugIdIdentifier="sentry-dbid-15f1eb19-511d-4c3e-8417-8a18a3aaa1ec")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new d().logoutCallback()}),(a,l)=>(b(),f("div",null,[o(t(_),null,{default:n(()=>[r(s(t(i).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(t(p),null,{default:n(()=>[r(s(t(i).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-CMe3vl7B.js.map
