import{N as c}from"./Navbar-hM5W_gyU.js";import{e as d,al as u,b as a,l,a5 as f,f as _,g as b,v as p,k as y,aO as I}from"./jwt-decode.esm-Da8x-1xB.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-C4GVg7LU.js";import"./constants-CAYghYvd.js";import"./PhCaretDown.vue-CbUX93Ko.js";import"./PhPencilSimple.vue-DK1Qj1mM.js";import"./router-BJvrxFV-.js";import"./ts.worker-CqdC973H.js";import"./organization-JjDSjWc-.js";import"./tables-CPbk6DmS.js";import"./string-CLQB_5TN.js";import"./keyboard-Dd-sAifX.js";import"./os-hQbnZA5r.js";import"./projectStore-BjD-_RaD.js";import"./project-yMEbyW-E.js";import"./organizationSwitcher-CmXXcal6.js";import"./cascaderStore-BP4pZiOg.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-BmfTSd-U.js";import"./member-NKjoz5r1.js";import"./index-BsP9txxR.js";import"./index-BK7IKiwl.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-C-9VnZ5G.js";import"./PhNotePencil.vue-KRlhIt2t.js";import"./PhSignOut.vue-DCenLPwB.js";import"./index-DdU81r5b.js";import"./index-8ZY2fr3u.js";import"./PhPlus.vue-9e8-FOx9.js";import"./omniChatStore-B4TMVcsy.js";import"./files-BEgOq74j.js";import"./contracts.generated-BDOilB4N.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";import"./uuid-BPwEXAQs.js";import"./PhCopySimple.vue-CNe6iZi1.js";import"./useLintersStore-CWPDZ4c7.js";import"./webSocketService-DgPUjI2c.js";import"./PhSparkle.vue-CACChjGY.js";import"./index-BRT_IYd7.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="9ebad28b-9f0f-4365-a2e4-417122b15063",r._sentryDebugIdIdentifier="sentry-dbid-9ebad28b-9f0f-4365-a2e4-417122b15063")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(e)])])}}}),no=I(w,[["__scopeId","data-v-62f8634d"]]);export{no as default};
//# sourceMappingURL=ConsoleLayout-9JHO-2Iw.js.map
