import{am as d}from"./jwt-decode.esm-Da8x-1xB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9892ae53-192d-40e4-aa4b-2d5966a85e82",e._sentryDebugIdIdentifier="sentry-dbid-9892ae53-192d-40e4-aa4b-2d5966a85e82")}catch{}})();var a=4;function o(e){return d(e,a)}export{o as c};
//# sourceMappingURL=clone-bU6nKxPX.js.map
