import{e as _,ah as f,al as p,l as s,n as m,g as c,w as i,f as g,M as y,Y as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-Da8x-1xB.js";import{u as T}from"./projectStore-BjD-_RaD.js";import{A as h,T as D}from"./index-BK7IKiwl.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="309389f4-7128-4162-9fce-c1797336725e",e._sentryDebugIdIdentifier="sentry-dbid-309389f4-7128-4162-9fce-c1797336725e")}catch{}})();const N=_({__name:"TablesTabs",setup(e){const a=f(),r=p(),u=String(r.name),d=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=l=>{a.push({name:String(l),params:{projectId:d.projectId}})};return(l,S)=>(c(),m(n(D),{"active-key":n(u),options:o,"onUpdate:activeKey":b},{default:i(()=>[(c(),g(y,null,v(o,t=>k(n(h),{key:t.value,name:t.value},{tab:i(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-DdksMJM7.js.map
