import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-Cryu-Vny.js";import{e as d,f as i,v as u,p as n,ah as f,al as m,g as l,aO as _}from"./jwt-decode.esm-Da8x-1xB.js";import{u as g}from"./workspaceStore-sWJCG1kE.js";import"./OTPInput-D6Fi9zOP.js";import"./Logo-RPAetcP3.js";import"./string-CLQB_5TN.js";import"./CircularLoading-B5VLBjSJ.js";import"./index-BJ99xF-g.js";import"./userStore-B4jqUwEL.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b7a35f2e-4c7f-49e3-a77f-1cd51a7d5c1f",e._sentryDebugIdIdentifier="sentry-dbid-b7a35f2e-4c7f-49e3-a77f-1cd51a7d5c1f")}catch{}})();const y={class:"runner"},b=d({__name:"Login",setup(e){const o=f(),r=m(),a=g(),c=async()=>{const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(l(),i("div",y,[u(p,{"logo-url":n(a).state.workspace?.logoUrl??void 0,"brand-name":n(a).state.workspace?.brandName,locale:n(a).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(b,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-Cr8QP1FF.js.map
