import{P as g}from"./PlayerNavbar-DAgkCdH9.js";import{e as h,al as i,r as _,b,f as y,n as k,j as w,k as v,p as a,v as L,a5 as C,ah as I,g as c,aO as N}from"./jwt-decode.esm-Da8x-1xB.js";import{u as V}from"./workspaceStore-sWJCG1kE.js";import"./userStore-B4jqUwEL.js";import"./metadata-DrICDQBk.js";import"./PhCursorClick.vue-CXFAK_Y9.js";import"./PhHouse.vue-tkMOCcnC.js";import"./PhMagnifyingGlass.vue-C4J75yyG.js";import"./PhWebhooksLogo.vue-kd7Zejxh.js";import"./LoadingOutlined-BkOwXhRU.js";import"./PhSignOut.vue-DCenLPwB.js";import"./index-8ZY2fr3u.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="810b8ba8-c0a1-4db6-a749-dfec575a183d",o._sentryDebugIdIdentifier="sentry-dbid-810b8ba8-c0a1-4db6-a749-dfec575a183d")}catch{}})();const B={class:"main-container"},D={class:"content"},P=h({__name:"Main",setup(o){const e=I(),t=V(),d=i().path,n=_(null),p=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},u=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),y("div",B,[a(t).state.workspace?(c(),k(g,{key:0,"current-path":a(d),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:p,onLoginClick:l,onLogoutClick:u},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(f)])])}}}),H=N(P,[["__scopeId","data-v-61bdccea"]]);export{H as default};
//# sourceMappingURL=Main-Cj2O_3fX.js.map
