import{L as u}from"./CircularLoading-B5VLBjSJ.js";import{e as f,al as p,R as _,f as h,g as l,k as c,v as g,aO as m}from"./jwt-decode.esm-Da8x-1xB.js";import{E as r,a as y}from"./router-BJvrxFV-.js";import"./ts.worker-CqdC973H.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e459b203-baad-47df-bd44-885e7d97466a",e._sentryDebugIdIdentifier="sentry-dbid-e459b203-baad-47df-bd44-885e7d97466a")}catch{}})();const b={class:"authorize"},w={class:"content"},A=f({__name:"Authorize",setup(e){const o=p();return _(()=>{const{client_id:a,redirect_uri:s,response_type:n,state:i}=o.query,t=r.cloudApi.startsWith("https://")||r.cloudApi.startsWith("http://")?new URL(`${r.cloudApi}/oauth/authorize`):new URL(`${location.origin}${r.cloudApi}/oauth/authorize`);typeof a=="string"&&t.searchParams.set("client_id",a),typeof s=="string"&&t.searchParams.set("redirect_uri",s),typeof n=="string"&&t.searchParams.set("response_type",n),typeof i=="string"&&t.searchParams.set("state",i);const d=y.getAuthor();d?.jwt&&t.searchParams.set("session_token",d.jwt),window.location.href=t.toString()}),(a,s)=>(l(),h("div",b,[c("div",w,[s[0]||(s[0]=c("h1",null,"Authorizing...",-1)),g(u)])]))}}),L=m(A,[["__scopeId","data-v-57fe5408"]]);export{L as default};
//# sourceMappingURL=Authorize-D9rxZaXp.js.map
