import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-CBb8tm9r.js";import{B as y}from"./BaseLayout-fW9ZWx2R.js";import{e as l,U as _,a2 as b,aO as u,aK as v,aL as g,g as m,f as h,k as o,J as s,R as w,ah as S,n as k,w as n,al as B,v as i,p as I}from"./jwt-decode.esm-Da8x-1xB.js";import{u as L}from"./editor-D9FjYD2q.js";import{A as $}from"./index-BRT_IYd7.js";import"./logo-BiWG9_W5.js";import"./Logo-RPAetcP3.js";import"./ts.worker-CqdC973H.js";import"./workspaceStore-sWJCG1kE.js";import"./userStore-B4jqUwEL.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";import"./useCodebaseEvents-pOy82kT7.js";import"./contracts.generated-BDOilB4N.js";import"./webSocketService-DgPUjI2c.js";import"./useLintersStore-CWPDZ4c7.js";import"./files-BEgOq74j.js";import"./router-D486464k.js";import"./constants-CAYghYvd.js";import"./index-DdU81r5b.js";import"./index-8ZY2fr3u.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="5577918a-8ad2-4a55-854b-b19ffa007402",e._sentryDebugIdIdentifier="sentry-dbid-5577918a-8ad2-4a55-854b-b19ffa007402")}catch{}})();const R=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),x={class:"v-spinner"};function D(e,r,a,d,p,c){return v((m(),h("div",x,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(R,[["render",D],["__scopeId","data-v-224007fd"]]),P={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),d=L();function p(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function c(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=c();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(p),a.push({name:"editor"})}),(t,A)=>(m(),k(y,null,{navbar:n(()=>[i(I($),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[o("div",P,[i(K)])]),_:1}))}}),ae=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{ae as default};
//# sourceMappingURL=ProjectLogin-CxGPP2mU.js.map
