import{aX as r,aY as n,a6 as o,aZ as d,a_ as p,a$ as c,b0 as f,b1 as b,b2 as m,b3 as s,b4 as u,b5 as g,b6 as l}from"./jwt-decode.esm-Da8x-1xB.js";import{b as y,s as w,g as _}from"./workspaceStore-sWJCG1kE.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-Caneqxm0.js";import{r as i}from"./router-D486464k.js";import"./userStore-B4jqUwEL.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";import"./PlayerConfigProvider-MiseMz11.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="f2edfab6-4d20-4b79-973f-1ec6a0c2ddf7",t._sentryDebugIdIdentifier="sentry-dbid-f2edfab6-4d20-4b79-973f-1ec6a0c2ddf7")}catch{}})();class I{static init(){setInterval(()=>{y("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await _(),a=r(),e=n({render:()=>o(h)});d.init(),p(e,i,t),I.init(),e.use(i),e.use(a),e.use(c),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",b),e.component("Message",m),s(e,u),s(e,g),s(e,l)})();
//# sourceMappingURL=player-CfChIzaa.js.map
