import{B as c}from"./BaseLayout-fW9ZWx2R.js";import{C as p}from"./ContentLayout-BfegT687.js";import{e as f,al as _,b as i,G as g,a5 as b,n as r,g as s,w as m,v as y,j as w}from"./jwt-decode.esm-Da8x-1xB.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-D1dLA_vS.js";import{u as z}from"./projectsStore-BHyaoZ4q.js";import"./router-BJvrxFV-.js";import"./ts.worker-CqdC973H.js";import"./index-BJ99xF-g.js";import"./member-NKjoz5r1.js";import"./organization-JjDSjWc-.js";import"./project-yMEbyW-E.js";import"./tables-CPbk6DmS.js";import"./string-CLQB_5TN.js";import"./cascaderStore-BP4pZiOg.js";import"./organizationSwitcher-CmXXcal6.js";import"./ant-design-BlBUcvFV.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="9193f5a5-b57d-41a8-a88a-7979edd40a44",t._sentryDebugIdIdentifier="sentry-dbid-9193f5a5-b57d-41a8-a88a-7979edd40a44")}catch{}})();const P=f({__name:"Organization",setup(t){const e=_(),a=z(),n=i(()=>e.params.organizationId);g(n,o=>{o&&a.fetchedState?.organization?.id!==o&&a.fetchState(o)},{immediate:!0});const u=i(()=>a.fetchedState?.organization),d=i(()=>u.value?.billingMetadata);return(o,h)=>{const l=b("RouterView");return s(),r(c,null,{content:m(()=>[y(p,null,{default:m(()=>[d.value?(s(),r(v,{key:0,"billing-metadata":d.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(l,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-DPFXigcm.js.map
