import{u as r}from"./userStore-B4jqUwEL.js";import{W as n}from"./PlayerConfigProvider-MiseMz11.js";import{u as c}from"./workspaceStore-sWJCG1kE.js";import{e as i,G as f,n as m,j as d,p as o,w as u,v as p,a5 as l,g as w}from"./jwt-decode.esm-Da8x-1xB.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="c503e43a-a00c-4625-9215-1e333577fb6c",t._sentryDebugIdIdentifier="sentry-dbid-c503e43a-a00c-4625-9215-1e333577fb6c")}catch{}})();const C=i({__name:"App",setup(t){document.documentElement.dataset.theme="light";const a=r(),e=c();return e.actions.fetch(),f(()=>a.jwt,e.actions.fetch),(_,g)=>{const s=l("RouterView");return o(e).state.workspace?(w(),m(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[p(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):d("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-Caneqxm0.js.map
