import{O as l}from"./workspaceStore-sWJCG1kE.js";import{e as c,R as f,f as u,v as n,w as o,p as a,an as _,T as p,q as r,t as i,l as s,g as b}from"./jwt-decode.esm-Da8x-1xB.js";import"./userStore-B4jqUwEL.js";import"./runnerData-Ck30Znt6.js";import"./url-WpgygH3Q.js";import"./colorHelpers-DWgwf-SH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c00dfb02-8bac-4e9e-8c99-24d59ff1304f",e._sentryDebugIdIdentifier="sentry-dbid-c00dfb02-8bac-4e9e-8c99-24d59ff1304f")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,d)=>(b(),u("div",null,[n(a(_),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(p),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-BMiWErLk.js.map
