import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-D9cBz4RQ.js";import{e as i,n,g as m,p as s}from"./jwt-decode.esm-Da8x-1xB.js";import{u as a}from"./projectStore-BjD-_RaD.js";import"./router-BJvrxFV-.js";import"./ts.worker-CqdC973H.js";import"./fetch-XZ2P4vxw.js";import"./tables-CPbk6DmS.js";import"./string-CLQB_5TN.js";import"./SaveButton-DeFXteG1.js";import"./ExclamationCircleOutlined-LeXEznj9.js";import"./CrudView-CH_Qmkqu.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-CarPIGsK.js";import"./constants-CAYghYvd.js";import"./url-WpgygH3Q.js";import"./PhDotsThreeVertical.vue-D84GFoAU.js";import"./index-DdU81r5b.js";import"./asyncComputed-J78O2Y__.js";import"./PhPencil.vue-BpHFQC0g.js";import"./useCodebaseEvents-pOy82kT7.js";import"./contracts.generated-BDOilB4N.js";import"./webSocketService-DgPUjI2c.js";import"./index-BJ99xF-g.js";import"./project-yMEbyW-E.js";import"./organizationSwitcher-CmXXcal6.js";import"./organization-JjDSjWc-.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="8ee72e48-81b2-4fd7-9c48-60a20c55f49c",o._sentryDebugIdIdentifier="sentry-dbid-8ee72e48-81b2-4fd7-9c48-60a20c55f49c")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(c,f)=>(m(),n(p,{"env-var-repository":s(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-D3CtH4Rw.js.map
